@@ -10,7 +10,6 @@
 
 namespace KAuth
 {
-
 TestBackend::TestBackend()
     : AuthBackend()
 {
@@ -68,11 +67,11 @@ bool TestBackend::isCallerAuthorized(const QString &action, const QByteArray &ca
         return false;
     } else if (action == QLatin1String("requires.auth")) {
         m_actionStatuses.insert(action, Action::AuthorizedStatus);
-        emit actionStatusChanged(action, Action::AuthorizedStatus);
+        Q_EMIT actionStatusChanged(action, Action::AuthorizedStatus);
         return true;
     } else if (action == QLatin1String("generates.error")) {
         m_actionStatuses.insert(action, Action::ErrorStatus);
-        emit actionStatusChanged(action, Action::ErrorStatus);
+        Q_EMIT actionStatusChanged(action, Action::ErrorStatus);
         return false;
     } else if (action == QLatin1String("always.authorized")) {
         return true;
@@ -80,11 +79,11 @@ bool TestBackend::isCallerAuthorized(const QString &action, const QByteArray &ca
         qDebug() << "Caller ID:" << callerId;
         if (callerId == callerID()) {
             m_actionStatuses.insert(action, Action::AuthorizedStatus);
-            emit actionStatusChanged(action, Action::AuthorizedStatus);
+            Q_EMIT actionStatusChanged(action, Action::AuthorizedStatus);
             return true;
         } else {
             m_actionStatuses.insert(action, Action::DeniedStatus);
-            emit actionStatusChanged(action, Action::DeniedStatus);
+            Q_EMIT actionStatusChanged(action, Action::DeniedStatus);
         }
     }
 
@@ -94,12 +93,13 @@ bool TestBackend::isCallerAuthorized(const QString &action, const QByteArray &ca
 bool TestBackend::actionExists(const QString &action)
 {
     qDebug() << "Checking if action " << action << "exists";
-    if (action != QLatin1String("doomed.to.fail") &&
-            action != QLatin1String("requires.auth") &&
-            action != QLatin1String("generates.error") &&
-            action != QLatin1String("always.authorized") &&
-            action != QLatin1String("/safinvalid124%$&") &&
-            !action.startsWith(QLatin1String("org.kde.kf5auth.autotest"))) {
+    /* clang-format off */
+    if (action != QLatin1String("doomed.to.fail")
+        && action != QLatin1String("requires.auth")
+        && action != QLatin1String("generates.error")
+        && action != QLatin1String("always.authorized")
+        && action != QLatin1String("/safinvalid124%$&")
+        && !action.startsWith(QLatin1String("org.kde.kf5auth.autotest"))) { /* clang-format on */
         return false;
     }
 
@@ -107,3 +107,5 @@ bool TestBackend::actionExists(const QString &action)
 }
 
 } // namespace Auth
+
+#include "moc_TestBackend.cpp"
