@@ -5,16 +5,16 @@
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef HELPER_PROXY_H
-#define HELPER_PROXY_H
+#ifndef KAUTH_HELPER_PROXY_H
+#define KAUTH_HELPER_PROXY_H
 
 #include <QMap>
 #include <QObject>
 #include <QString>
 #include <QVariant>
 
-#include "kauthaction.h"
-#include "kauthactionreply.h"
+#include "action.h"
+#include "actionreply.h"
 
 namespace KAuth
 {
@@ -25,7 +25,7 @@ class HelperProxy : public QObject
     Q_OBJECT
 
 public:
-    virtual ~HelperProxy();
+    ~HelperProxy() override;
 
     // Application-side methods
     virtual void executeAction(const QString &action, const QString &helperID, const DetailsMap &details, const QVariantMap &arguments, int timeout) = 0;
@@ -37,7 +37,7 @@ public:
     virtual bool hasToStopAction() = 0;
     virtual void sendDebugMessage(int level, const char *msg) = 0;
     virtual void sendProgressStep(int step) = 0;
-    virtual void sendProgressStep(const QVariantMap &step) = 0;
+    virtual void sendProgressStepData(const QVariantMap &step) = 0;
     // Attempts to resolve the UID of the unprivileged remote process.
     virtual int callerUid() const = 0;
 
@@ -45,7 +45,7 @@ Q_SIGNALS:
     void actionStarted(const QString &action);
     void actionPerformed(const QString &action, const KAuth::ActionReply &reply);
     void progressStep(const QString &action, int progress);
-    void progressStep(const QString &action, const QVariantMap &data);
+    void progressStepData(const QString &action, const QVariantMap &data);
 };
 
 } // namespace KAuth
