@@ -7,24 +7,26 @@
 */
 
 #include "DBusHelperProxy.h"
-
-#include <qplugin.h>
-#include <QObject>
-#include <QMap>
-#include <QDBusMessage>
-#include <QTimer>
-#include <QMetaMethod>
-#include <QDBusConnectionInterface>
-
 #include "BackendsManager.h"
-#include "kf5authadaptor.h"
 #include "kauthdebug.h"
+#include "kf5authadaptor.h"
 
+#include <QDBusConnectionInterface>
+#include <QDBusMessage>
+#include <QMap>
+#include <QMetaMethod>
+#include <QObject>
+#include <QTimer>
+#include <qplugin.h>
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+extern Q_CORE_EXPORT const QtPrivate::QMetaTypeInterface *qMetaTypeGuiHelper;
+#else
 extern Q_CORE_EXPORT const QMetaTypeInterface *qMetaTypeGuiHelper;
+#endif
 
 namespace KAuth
 {
-
 static void debugMessageReceived(int t, const QString &message);
 
 DBusHelperProxy::DBusHelperProxy()
@@ -65,25 +67,28 @@ void DBusHelperProxy::executeAction(const QString &action, const QString &helper
         stream << arguments;
     }
 
-    //on unit tests we won't have a service, but the service will already be running
+    // on unit tests we won't have a service, but the service will already be running
     const auto reply = m_busConnection.interface()->startService(helperID);
     if (!reply.isValid() && !m_busConnection.interface()->isServiceRegistered(helperID)) {
         ActionReply errorReply = ActionReply::DBusErrorReply();
         errorReply.setErrorDescription(tr("DBus Backend error: service start %1 failed: %2").arg(helperID, reply.error().message()));
-        emit actionPerformed(action, errorReply);
+        Q_EMIT actionPerformed(action, errorReply);
         return;
     }
 
-    const bool connected = m_busConnection.connect(helperID, QLatin1String("/"), QLatin1String("org.kde.kf5auth"), QLatin1String("remoteSignal"), this, SLOT(remoteSignalReceived(int,QString,QByteArray)));
+    const bool connected = m_busConnection.connect(helperID,
+                                                   QLatin1String("/"),
+                                                   QLatin1String("org.kde.kf5auth"),
+                                                   QLatin1String("remoteSignal"),
+                                                   this,
+                                                   SLOT(remoteSignalReceived(int, QString, QByteArray)));
 
-    //if already connected reply will be false but we won't have an error or a reason to fail
+    // if already connected reply will be false but we won't have an error or a reason to fail
     if (!connected && m_busConnection.lastError().isValid()) {
         ActionReply errorReply = ActionReply::DBusErrorReply();
-        errorReply.setErrorDescription(tr("DBus Backend error: connection to helper failed. %1\n(application: %2 helper: %3)").arg(
-                m_busConnection.lastError().message(),
-                qApp->applicationName(),
-                helperID));
-        emit actionPerformed(action, errorReply);
+        errorReply.setErrorDescription(tr("DBus Backend error: connection to helper failed. %1\n(application: %2 helper: %3)")
+                                           .arg(m_busConnection.lastError().message(), qApp->applicationName(), helperID));
+        Q_EMIT actionPerformed(action, errorReply);
         return;
     }
 
@@ -100,7 +105,7 @@ void DBusHelperProxy::executeAction(const QString &action, const QString &helper
 
     auto watcher = new QDBusPendingCallWatcher(pendingCall, this);
 
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] () mutable {
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [=]() mutable {
         watcher->deleteLater();
 
         QDBusMessage reply = watcher->reply();
@@ -117,10 +122,11 @@ void DBusHelperProxy::executeAction(const QString &action, const QString &helper
             }
             ActionReply r = ActionReply::DBusErrorReply();
             r.setErrorDescription(tr("DBus Backend error: could not contact the helper. "
-                                    "Connection error: %1. Message error: %2").arg(reply.errorMessage(), m_busConnection.lastError().message()));
+                                     "Connection error: %1. Message error: %2")
+                                      .arg(reply.errorMessage(), m_busConnection.lastError().message()));
             qCWarning(KAUTH) << reply.errorMessage();
 
-            emit actionPerformed(action, r);
+            Q_EMIT actionPerformed(action, r);
         }
     });
 }
@@ -155,12 +161,12 @@ void DBusHelperProxy::remoteSignalReceived(int t, const QString &action, QByteAr
     QDataStream stream(&blob, QIODevice::ReadOnly);
 
     if (type == ActionStarted) {
-        emit actionStarted(action);
+        Q_EMIT actionStarted(action);
     } else if (type == ActionPerformed) {
         ActionReply reply = ActionReply::deserialize(blob);
 
         m_actionsInProgress.removeOne(action);
-        emit actionPerformed(action, reply);
+        Q_EMIT actionPerformed(action, reply);
     } else if (type == DebugMessage) {
         int level;
         QString message;
@@ -172,19 +178,18 @@ void DBusHelperProxy::remoteSignalReceived(int t, const QString &action, QByteAr
         int step;
         stream >> step;
 
-        emit progressStep(action, step);
+        Q_EMIT progressStep(action, step);
     } else if (type == ProgressStepData) {
         QVariantMap data;
         stream >> data;
-
-        emit progressStep(action, data);
+        Q_EMIT progressStepData(action, data);
     }
 }
 
 void DBusHelperProxy::stopAction(const QString &action)
 {
     Q_UNUSED(action)
-//#warning FIXME: The stop request should be action-specific rather than global
+    //#warning FIXME: The stop request should be action-specific rather than global
     m_stopRequest = true;
 }
 
@@ -200,19 +205,19 @@ bool DBusHelperProxy::isCallerAuthorized(const QString &action, const QByteArray
 {
     // Check the caller is really who it says it is
     switch (BackendsManager::authBackend()->extraCallerIDVerificationMethod()) {
-        case AuthBackend::NoExtraCallerIDVerificationMethod:
+    case AuthBackend::NoExtraCallerIDVerificationMethod:
         break;
 
-        case AuthBackend::VerifyAgainstDBusServiceName:
-            if (message().service().toUtf8() != callerID) {
-                return false;
-            }
+    case AuthBackend::VerifyAgainstDBusServiceName:
+        if (message().service().toUtf8() != callerID) {
+            return false;
+        }
         break;
 
-        case AuthBackend::VerifyAgainstDBusServicePid:
-            if (connection().interface()->servicePid(message().service()).value() != callerID.toUInt()) {
-                return false;
-            }
+    case AuthBackend::VerifyAgainstDBusServicePid:
+        if (connection().interface()->servicePid(message().service()).value() != callerID.toUInt()) {
+            return false;
+        }
         break;
     }
 
@@ -241,7 +246,7 @@ QByteArray DBusHelperProxy::performAction(const QString &action, const QByteArra
     qMetaTypeGuiHelper = origMetaTypeGuiHelper;
 
     m_currentAction = action;
-    emit remoteSignal(ActionStarted, action, QByteArray());
+    Q_EMIT remoteSignal(ActionStarted, action, QByteArray());
     QEventLoop e;
     e.processEvents(QEventLoop::AllEvents);
 
@@ -272,11 +277,9 @@ QByteArray DBusHelperProxy::performAction(const QString &action, const QByteArra
             const auto needle = "KAuth::";
             bool success = false;
             if (strncmp(needle, method.typeName(), strlen(needle)) == 0) {
-                success = method.invoke(responder, Qt::DirectConnection,
-                                        Q_RETURN_ARG(KAuth::ActionReply, retVal), Q_ARG(QVariantMap, args));
+                success = method.invoke(responder, Qt::DirectConnection, Q_RETURN_ARG(KAuth::ActionReply, retVal), Q_ARG(QVariantMap, args));
             } else {
-                success = method.invoke(responder, Qt::DirectConnection,
-                                        Q_RETURN_ARG(ActionReply, retVal), Q_ARG(QVariantMap, args));
+                success = method.invoke(responder, Qt::DirectConnection, Q_RETURN_ARG(ActionReply, retVal), Q_ARG(QVariantMap, args));
             }
             if (!success) {
                 retVal = ActionReply::NoSuchActionReply();
@@ -290,7 +293,7 @@ QByteArray DBusHelperProxy::performAction(const QString &action, const QByteArra
 
     timer->start();
 
-    emit remoteSignal(ActionPerformed, action, retVal.serialized());
+    Q_EMIT remoteSignal(ActionPerformed, action, retVal.serialized());
     e.processEvents(QEventLoop::AllEvents);
     m_currentAction.clear();
     m_stopRequest = false;
@@ -305,7 +308,7 @@ void DBusHelperProxy::sendDebugMessage(int level, const char *msg)
 
     stream << level << QString::fromLocal8Bit(msg);
 
-    emit remoteSignal(DebugMessage, m_currentAction, blob);
+    Q_EMIT remoteSignal(DebugMessage, m_currentAction, blob);
 }
 
 void DBusHelperProxy::sendProgressStep(int step)
@@ -315,17 +318,17 @@ void DBusHelperProxy::sendProgressStep(int step)
 
     stream << step;
 
-    emit remoteSignal(ProgressStepIndicator, m_currentAction, blob);
+    Q_EMIT remoteSignal(ProgressStepIndicator, m_currentAction, blob);
 }
 
-void DBusHelperProxy::sendProgressStep(const QVariantMap &data)
+void DBusHelperProxy::sendProgressStepData(const QVariantMap &data)
 {
     QByteArray blob;
     QDataStream stream(&blob, QIODevice::WriteOnly);
 
     stream << data;
 
-    emit remoteSignal(ProgressStepData, m_currentAction, blob);
+    Q_EMIT remoteSignal(ProgressStepData, m_currentAction, blob);
 }
 
 void debugMessageReceived(int t, const QString &message)
@@ -360,3 +363,5 @@ int DBusHelperProxy::callerUid() const
 }
 
 } // namespace Auth
+
+#include "moc_DBusHelperProxy.cpp"
